@@ -70,4 +70,19 @@ def _simulate_parser(prog="simulate", description=DESCRIPTION_SIMULATE):
              "Only used when --prior_excluded is not given. "
              f"Default {DEFAULT_N_PRIOR_EXCLUDED}")
 
+    parser.add_argument(
+        "--prior_idx",
+        default=[],
+        nargs="*",
+        type=int,
+        help="Prior indices by id."
+    )
+    parser.add_argument(
+        '--init_seed',
+        default=None,
+        type=int,
+        help="Seed for setting the prior indices if the --prior_idx option is "
+             "not used. If the option --prior_idx is used with one or more "
+             "index, this option is ignored."
+    )
     return parser
