@@ -1,38 +1,51 @@
-import shutil
-import os
-import re
 import json
 import logging
+import os
+import re
+import shutil
 import subprocess
-import shlex
-from urllib.request import urlretrieve
 import urllib.parse
-
-
-from flask.json import jsonify
-from flask_cors import CORS
-from flask import request, Blueprint, Response
-from werkzeug.utils import secure_filename
+from copy import deepcopy
+from pathlib import Path
+from urllib.request import urlretrieve
 
 import numpy as np
+from flask import Blueprint
+from flask import current_app as app
+from flask import request
+from flask import Response
+from flask import send_file
+from flask.json import jsonify
+from flask_cors import CORS
+from werkzeug.utils import secure_filename
 
-from asreview.datasets import get_dataset
-from asreview.webapp.utils.paths import list_asreview_project_paths
-from asreview.webapp.utils.paths import get_data_path, get_project_file_path
-from asreview.webapp.utils.paths import get_lock_path, get_proba_path
-from asreview.webapp.utils.paths import get_project_path
-from asreview.webapp.utils.project import get_paper_data, get_statistics,\
-    export_to_string
-from asreview.webapp.utils.project import label_instance
-from asreview.webapp.utils.project import get_instance
-from asreview.webapp.utils.project import init_project, read_data
-
-from asreview.webapp.types import is_project
-from asreview.webapp.utils.validation import check_dataset
-from asreview.webapp.utils.project import add_dataset_to_project
-from asreview.webapp.utils.datasets import search_data, get_data_statistics
+from asreview.datasets import DatasetManager
+from asreview.exceptions import BadFileFormatError
 from asreview.webapp.sqlock import SQLiteLock
-from asreview.webapp.utils.io import read_pool, read_label_history
+from asreview.webapp.types import is_project
+from asreview.webapp.utils.datasets import get_data_statistics
+from asreview.webapp.utils.datasets import get_dataset_metadata
+from asreview.webapp.utils.datasets import search_data
+from asreview.webapp.utils.io import read_label_history
+from asreview.webapp.utils.io import read_pool
+from asreview.webapp.utils.paths import get_data_path
+from asreview.webapp.utils.paths import get_kwargs_path
+from asreview.webapp.utils.paths import get_lock_path
+from asreview.webapp.utils.paths import get_proba_path
+from asreview.webapp.utils.paths import get_project_file_path
+from asreview.webapp.utils.paths import get_project_path
+from asreview.webapp.utils.paths import get_tmp_path
+from asreview.webapp.utils.paths import list_asreview_project_paths
+from asreview.webapp.utils.project import _get_executable
+from asreview.webapp.utils.project import add_dataset_to_project
+from asreview.webapp.utils.project import export_to_string
+from asreview.webapp.utils.project import get_instance
+from asreview.webapp.utils.project import get_paper_data
+from asreview.webapp.utils.project import get_statistics
+from asreview.webapp.utils.project import init_project
+from asreview.webapp.utils.project import label_instance
+from asreview.webapp.utils.project import read_data
+from asreview.webapp.utils.validation import check_dataset
 
 
 bp = Blueprint('api', __name__, url_prefix='/api')
@@ -126,40 +139,18 @@ def api_init_project():  # noqa: F401
 def api_demo_data_project():  # noqa: F401
     """Get info on the article"""
 
-    print(request.args)
     subset = request.args.get('subset', None)
 
-    # clean this crappy code @TODO{Jonathan}
     if subset == "plugin":
-
-        from asreview.datasets import get_available_datasets
-
-        result_datasets = []
-        datasets = get_available_datasets()
-        for group_name, group in datasets.items():
-            for dataset_key, dataset in group.items():
-                if dataset.dataset_id not in ["hall", "ace", "ptsd"]:
-                    result_datasets.append(dataset.to_dict())
-
-        payload = {"result": result_datasets}
+        result_datasets = get_dataset_metadata(exclude="builtin")
     elif subset == "test":
-
-        from asreview.datasets import get_available_datasets
-
-        result_datasets = []
-        datasets = get_available_datasets()
-        for group_name, group in datasets.items():
-            for dataset_key, dataset in group.items():
-                if dataset.dataset_id in ["hall", "ace", "ptsd"]:
-                    result_datasets.append(dataset.to_dict())
-
-        payload = {"result": result_datasets}
-
+        result_datasets = get_dataset_metadata(include="builtin")
     else:
         response = jsonify(message="demo-data-loading-failed")
 
         return response, 400
 
+    payload = {"result": result_datasets}
     response = jsonify(payload)
     response.headers.add('Access-Control-Allow-Origin', '*')
     return response
@@ -176,7 +167,7 @@ def api_upload_data_project(project_id):  # noqa: F401
     if request.form.get('demo_data', None):
         # download file and save to folder
 
-        demo_data = get_dataset(request.form['demo_data'])
+        demo_data = DatasetManager().find(request.form['demo_data'])
 
         if demo_data.dataset_id in ["hall", "ace", "ptsd"]:
             download_url = demo_data.url_demo
@@ -191,22 +182,37 @@ def api_upload_data_project(project_id):  # noqa: F401
             get_data_path(project_id) / filename
         )
 
-        add_dataset_to_project(project_id, filename)
-
     elif request.form.get('url', None):
         # download file and save to folder
 
         download_url = request.form['url']
 
-        url_parts = urllib.parse.urlparse(download_url)
-        filename = secure_filename(url_parts.path.rsplit('/', 1)[-1])
+        try:
+            url_parts = urllib.parse.urlparse(download_url)
+            filename = secure_filename(url_parts.path.rsplit('/', 1)[-1])
 
-        urlretrieve(
-            download_url,
-            get_data_path(project_id) / filename
-        )
+            urlretrieve(
+                download_url,
+                get_data_path(project_id) / filename
+            )
 
-        add_dataset_to_project(project_id, filename)
+        except ValueError as err:
+
+            logging.error(err)
+            message = f"Invalid URL '{download_url}'."
+
+            if isinstance(download_url, str) \
+                    and not download_url.startswith("http"):
+                message += " Usually, the URL starts with 'http' or 'https'."
+
+            return jsonify(message=message), 400
+
+        except Exception as err:
+
+            logging.error(err)
+            message = f"Can't retrieve data from URL {download_url}."
+
+            return jsonify(message=message), 400
 
     elif 'file' in request.files:
 
@@ -222,8 +228,6 @@ def api_upload_data_project(project_id):  # noqa: F401
             # save the file
             data_file.save(str(fp_data))
 
-            add_dataset_to_project(project_id, filename)
-
         except Exception as err:
 
             logging.error(err)
@@ -237,16 +241,23 @@ def api_upload_data_project(project_id):  # noqa: F401
         response = jsonify(message="No file or dataset found to upload.")
         return response, 400
 
-    # get statistics of the dataset
     try:
-        statistics = get_data_statistics(project_id)
-    except Exception:
-        response = jsonify(
-            message=f"Failed to upload file '{filename}'. {err}"  # noqa
-        )
-        return response, 400
 
-    statistics["filename"] = filename
+        # add the file to the project
+        add_dataset_to_project(project_id, filename)
+
+        # get statistics of the dataset
+        statistics = get_data_statistics(project_id)
+        statistics["filename"] = filename
+
+    # Bad format. TODO{Jonathan} Return informative message with link.
+    except BadFileFormatError as err:
+        message = f"Failed to upload file '{filename}'. {err}"
+        return jsonify(message=message), 400
+
+    except Exception as err:
+        message = f"Failed to upload file '{filename}'. {err}"
+        return jsonify(message=message), 400
 
     response = jsonify(statistics)
     response.headers.add('Access-Control-Allow-Origin', '*')
@@ -391,9 +402,32 @@ def api_random_prior_papers(project_id):  # noqa: F401
 def api_start(project_id):  # noqa: F401
     """Start training the model
     """
+
+    # get the CLI arguments
+    asr_kwargs = deepcopy(app.config['asr_kwargs'])
+
+    # add the machine learning model to the kwargs
+    # TODO@{Jonathan} validate model choice on server side
+    ml_model = request.form.get("machine_learning_model", None)
+    if ml_model:
+        asr_kwargs["model"] = ml_model
+
+    # write the kwargs to a file
+    with open(get_kwargs_path(project_id), "w") as fp:
+        json.dump(asr_kwargs, fp)
+
     # start training the model
-    run_command = f"python -m asreview web_run_model '{project_id}' 1"
-    subprocess.Popen(shlex.split(run_command))
+
+    py_exe = _get_executable()
+    run_command = [
+        py_exe,
+        "-m", "asreview",
+        "web_run_model",
+        project_id,
+        "--label_method",
+        "prior"
+    ]
+    subprocess.Popen(run_command)
 
     response = jsonify({'success': True})
     response.headers.add('Access-Control-Allow-Origin', '*')
@@ -405,6 +439,13 @@ def api_init_model_ready(project_id):  # noqa: F401
     """Check if trained model is available
     """
 
+    error_path = get_project_path(project_id) / "error.json"
+    if error_path.exists():
+        print("error on training")
+        with open(error_path, "r") as f:
+            error_message = json.load(f)
+        return jsonify(error_message), 400
+
     if get_proba_path(project_id).exists():
         logging.info("Model trained - go to review screen")
         response = jsonify(
@@ -422,13 +463,31 @@ def api_init_model_ready(project_id):  # noqa: F401
 @bp.route('/project/<project_id>/export', methods=["GET"])
 def export_results(project_id):
 
-    dataset_str = export_to_string(project_id)
+    # get the export args
+    file_type = request.args.get('file_type', None)
+    logging.info(f"Start exporting results to '{file_type}'")
+    print(f"Start exporting results to '{file_type}'")
 
-    return Response(
-        dataset_str,
-        mimetype="text/csv",
-        headers={"Content-disposition":
-                 f"attachment; filename=asreview_result_{project_id}.csv"})
+    if file_type == "csv":
+        dataset_str = export_to_string(project_id, export_type="csv")
+
+        return Response(
+            dataset_str,
+            mimetype="text/csv",
+            headers={"Content-disposition":
+                     f"attachment; filename=asreview_result_{project_id}.csv"})
+    else:  # excel
+
+        dataset_str = export_to_string(project_id, export_type="excel")
+        fp_tmp_export = Path(get_tmp_path(project_id), "export_result.xlsx")
+
+        return send_file(
+            fp_tmp_export,
+            mimetype="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",  # noqa
+            as_attachment=True,
+            attachment_filename=f"asreview_result_{project_id}.xlsx",
+            cache_timeout=0
+        )
 
 
 # @bp.route('/project/<project_id>/document/<doc_id>/info', methods=["GET"])
@@ -501,14 +560,25 @@ def api_get_document(project_id):  # noqa: F401
     """
 
     new_instance = get_instance(project_id)
-    payload = get_paper_data(
-        project_id,
-        new_instance,
-        return_debug_label=True
-    )
-    payload["doc_id"] = new_instance
 
-    response = jsonify(payload)
+    if new_instance is None:  # don't use 'if not new_instance:'
+
+        item = None
+        pool_empty = True
+    else:
+
+        item = get_paper_data(
+            project_id,
+            new_instance,
+            return_debug_label=True
+        )
+        item["doc_id"] = new_instance
+        pool_empty = False
+
+    response = jsonify({
+        "result": item,
+        "pool_empty": pool_empty
+    })
     response.headers.add('Access-Control-Allow-Origin', '*')
     return response
 
