@@ -1,27 +1,42 @@
-from copy import deepcopy
 import json
-import os
 import logging
-import shlex
+import os
 import shutil
 import subprocess
+import sys
+from pathlib import Path
 
 import numpy as np
-from flask import current_app as app
 
 from asreview import __version__ as asreview_version
-from asreview.webapp.sqlock import SQLiteLock
-from asreview.webapp.utils.paths import get_project_file_path, get_state_path
-from asreview.webapp.utils.paths import get_kwargs_path
-from asreview.webapp.utils.paths import asreview_path
-from asreview.webapp.utils.paths import get_lock_path
-from asreview.webapp.utils.paths import get_data_file_path
-from asreview.webapp.utils.paths import get_pool_path
-from asreview.webapp.utils.paths import get_labeled_path
 from asreview.config import LABEL_NA
-from asreview.webapp.utils.io import read_pool, write_pool, read_label_history
-from asreview.webapp.utils.io import write_label_history, read_proba, read_data
+from asreview.webapp.sqlock import SQLiteLock
 from asreview.webapp.utils.io import read_current_labels
+from asreview.webapp.utils.io import read_data
+from asreview.webapp.utils.io import read_label_history
+from asreview.webapp.utils.io import read_pool
+from asreview.webapp.utils.io import read_proba
+from asreview.webapp.utils.io import write_label_history
+from asreview.webapp.utils.io import write_pool
+from asreview.webapp.utils.paths import asreview_path
+from asreview.webapp.utils.paths import get_data_file_path
+from asreview.webapp.utils.paths import get_labeled_path
+from asreview.webapp.utils.paths import get_lock_path
+from asreview.webapp.utils.paths import get_pool_path
+from asreview.webapp.utils.paths import get_project_file_path
+from asreview.webapp.utils.paths import get_tmp_path
+
+
+def _get_executable():
+    """Get the Python executable"""
+
+    py_exe = sys.executable
+
+    # if the exe is an empty string or None, then fall badck on 'python'
+    if not py_exe:
+        py_exe = 'python'
+
+    return py_exe
 
 
 def init_project(
@@ -58,13 +73,6 @@ def init_project(
                 'authors': project_authors
             }, fp)
 
-        asr_kwargs = deepcopy(app.config['asr_kwargs'])  # remove config
-        with open(get_kwargs_path(project_id), "w") as fp:
-            json.dump(asr_kwargs, fp)
-
-        # make a copy of the arguments to the state file
-        asr_kwargs['state_file'] = str(get_state_path(project_id))
-
     except Exception as err:
         # remove all generated folders and raise error
         shutil.rmtree(project_dir)
@@ -92,7 +100,12 @@ def add_dataset_to_project(project_id, file_name):
             json.dump(project_dict, f_write)
 
         # fill the pool of the first iteration
-        pool_indices = read_data(project_id).record_ids
+        as_data = read_data(project_id)
+        if as_data.labels is not None:
+            unlabeled = np.where(as_data.labels == LABEL_NA)[0]
+            pool_indices = as_data.record_ids[unlabeled]
+        else:
+            pool_indices = as_data.record_ids
         np.random.shuffle(pool_indices)
 
         write_pool(project_id, pool_indices.tolist())
@@ -179,8 +192,13 @@ def get_instance(project_id):
     with SQLiteLock(fp_lock, blocking=True, lock_name="active"):
         pool_idx = read_pool(project_id)
 
-    logging.info(f"Requesting {pool_idx[0]} from project {project_id}")
-    return pool_idx[0]
+    if len(pool_idx) > 0:
+        logging.info(f"Requesting {pool_idx[0]} from project {project_id}")
+        return pool_idx[0]
+    else:
+        # end of pool
+        logging.info(f"No more records for project {project_id}")
+        return None
 
 
 def get_statistics(project_id):
@@ -211,7 +229,7 @@ def get_statistics(project_id):
     return stats
 
 
-def export_to_string(project_id):
+def export_to_string(project_id, export_type="csv"):
     fp_lock = get_lock_path(project_id)
     as_data = read_data(project_id)
     with SQLiteLock(fp_lock, blocking=True, lock_name="active"):
@@ -229,7 +247,19 @@ def export_to_string(project_id):
     proba_order = np.argsort(-proba[pool_idx])
     ranking = np.concatenate(
         (one_idx, pool_idx[proba_order], zero_idx), axis=None)
-    return as_data.to_csv(fp=None, labels=labels, ranking=ranking)
+
+    if export_type == "csv":
+        return as_data.to_csv(fp=None, labels=labels, ranking=ranking)
+    if export_type == "excel":
+        get_tmp_path(project_id).mkdir(exist_ok=True)
+        fp_tmp_export = Path(get_tmp_path(project_id), "export_result.xlsx")
+        return as_data.to_excel(
+            fp=fp_tmp_export,
+            labels=labels,
+            ranking=ranking
+        )
+    else:
+        raise ValueError("This export type isn't implemented.")
 
 
 def label_instance(project_id, paper_i, label, retrain_model=True):
@@ -256,8 +286,15 @@ def label_instance(project_id, paper_i, label, retrain_model=True):
 
     if retrain_model:
         # Update the model (if it isn't busy).
-        run_command = f"python -m asreview web_run_model '{project_id}'"
-        subprocess.Popen(shlex.split(run_command))
+
+        py_exe = _get_executable()
+        run_command = [
+            py_exe,
+            "-m", "asreview",
+            "web_run_model",
+            project_id
+        ]
+        subprocess.Popen(run_command)
 
 
 def move_label_from_pool_to_labeled(project_id, paper_i, label):
